pub fn github_pull_request_url(
source: &SourceConfiguration,
number: u64,
) -> StringExpand description
Build a web URL for a pull request on the configured GitHub repository.
pub fn github_pull_request_url(
source: &SourceConfiguration,
number: u64,
) -> StringBuild a web URL for a pull request on the configured GitHub repository.